@@ -72,7 +72,7 @@ int closedir(DIR *dir);
 #endif
 
 int z_scandir (char *dir, struct dirent ***namelist, int (*select) (const char *, const struct dirent *), int (*cmp) (const void *, const void *));
-void z_free_namelist(struct dirent **namelist, int namelistlen);
+void z_free_namelist(struct dirent ***namelist, int *namelistlen);
 int z_select_dir_func(const char *, const struct dirent *de);
 int z_select_file_func(const char *, const struct dirent *de);
 int z_compare_name_func(const void *d1, const void *d2);
