@@ -15,7 +15,7 @@
 
 #define ZLOC_R_EARTH 6371.2907
 
-double qth(char *qth,int width);
+double qth(const char *qth,int width);
 char *compute_wwl4(char *s, double h, double w);
 char *mkwwl4(char *buf, int w, int h);
 char *hw2loc(char *buf, double w, double h, int len);
@@ -29,6 +29,7 @@ void hw2km_f(double h1, double w1, double h2, double w2, float *kx, float *ky);
 void km2qrbqtf(int kx, int ky, double *qrb, double *qtf);
 
 int qrbqtf2hw(double h1, double w1, double qrb, double qtf, double *h2, double *w2);
+int qrbqtf2lonlat(double h1, double w1, double qrb, double qtf_deg, double* lon, double* lat);
 int qsopwr( char *myqth, char *recqth);
 int qthwr(char *qth,int width);
 void qrb_qtf_int(char *mywwl, char *wwl, int *qrb_int, int *qtf_int);
