@@ -58,9 +58,10 @@ void debug_set_handlers(char *file, int line,
 #define set_handlers(n, r, w, x, a) debug_set_handlers(__FILE__, __LINE__, n, r, w, x, a, #r, #w, #x);
 #else                       */
 #define zselect_timer_new(zsel, ztime, fn, arg) zselect_timer_new_dbg((zsel), (ztime), (fn), (#fn), arg) 
-int zselect_timer_new_dbg(struct zselect *zsel, ztime, void (*)(void *), char *fname, void *arg); /* todo argument callbacku */
+int zselect_timer_new_dbg(struct zselect *zsel, ztime, void (*)(void *), const char *fname, void *arg); /* todo argument callbacku */
 int zselect_timer_new_at(struct zselect *zsel, struct timeval *at, void (*)(void *), void *arg);
-void zselect_timer_kill(struct zselect *zsel, int);
+#define zselect_timer_kill(zsel, id) zselect_timer_kill_dbg((zsel), (id), __FUNCTION__)
+void zselect_timer_kill_dbg(struct zselect *zsel, int, const char* fname);
 #define zselect_set(zsel, fd, read_fn, write_fn, error_fn, arg) zselect_set_dbg((zsel), (fd), (read_fn), (#read_fn), (write_fn), (#write_fn), (error_fn), (#error_fn), (arg))
 void zselect_set_dbg(struct zselect *zsel, int, void (*)(void *), char *, void (*)(void *), char *, void (*)(void *), char *, void *arg);
 void zselect_set_read(struct zselect *zsel, int fd, void (*write_func)(void *), void *arg);
@@ -96,7 +97,7 @@ int zselect_msg_send_raw(struct zselect *zsel, char *s);
 
 void zselect_start_profile(struct zselect *zsel, double limit);                      
 void zselect_hint(struct zselect *zsel, const char *fmt, ...);
-void zselect_handle_profile(struct zselect *zsel, struct timeval *start, void *fce, char *fname); 
+void zselect_handle_profile(struct zselect *zsel, struct timeval *start, void *fce, const char *fname); 
 int zselect_profiling(struct zselect *zsel);
 
 void zselect_abort_exception(void *arg);
