@@ -235,6 +235,30 @@ int qrbqtf2hw(double h1, double w1, double qrb, double qtf, double *h2, double *
     return 0;
 }
 
+/* qtf in degrees */
+int qrbqtf2lonlat(double h1, double w1, double qrb, double qtf_deg, double* lon, double* lat) {
+    double dh, d;
+
+    if (qrb > ZLOC_R_EARTH * M_PI) return -1;
+    d = qrb / ZLOC_R_EARTH;
+
+	double qtf_rad = qtf_deg * M_PI / 180.0;
+    double h2;
+    double w2 = asin(sin(w1) * cos(d) + cos(w1) * sin(d) * cos(qtf_rad));
+    if (fabs(cos(w2)) < EPSILON) {
+        h2 = 0;
+    }
+    else {
+        dh = atan2(sin(qtf_rad) * sin(d) * cos(w1),
+            cos(d) - sin(w1) * sin(w2));
+        h2 = fmod(M_PI + h1 + dh, 2 * M_PI) - M_PI;
+    }
+
+	*lon = h2 * 180.0 / M_PI;
+	*lat = w2 * 180.0 / M_PI;
+    return 0;
+}
+
 /*************** WWL RING *****************************/
 
 int qthwr(char *qth,int width) {
