@@ -70,7 +70,7 @@ struct ztimer {
     void *arg;
     int id;
 //#ifdef Z_LEAK_DEBUG_LIST
-    char *fname;    
+    const char *fname;    
 //#endif
 };
 
@@ -283,7 +283,7 @@ static void zselect_timers_check(struct zselect *zsel)
 int debug_install_timer(char *file, int line, ztime t, void (*func)(void *), void *arg, char *fname)
 #else    
 //int zselect_timer_new(struct zselect *zsel, ztime t, void (*func)(void *), void *arg)
-int zselect_timer_new_dbg(struct zselect *zsel, ztime t, void (*func)(void *), char *fname, void *arg)
+int zselect_timer_new_dbg(struct zselect *zsel, ztime t, void (*func)(void *), const char *fname, void *arg)
 #endif    
 {
     struct ztimer *tm, *tt;
@@ -293,7 +293,6 @@ int zselect_timer_new_dbg(struct zselect *zsel, ztime t, void (*func)(void *), c
 #else            
     tm = g_new(struct ztimer, 1);
 #endif        
-    if (!tm) return -1;
     tm->interval = t;
     tm->func = func;
 	tm->fname = fname;
@@ -318,6 +317,9 @@ int zselect_timer_new_dbg(struct zselect *zsel, ztime t, void (*func)(void *), c
 	}
 	dbg("\n");
 #endif	
+#if 1
+	if (strncmp(fname, "rain", 4) == 0) dbg("zselect_timer_new('%s', %ldms) = %d\n", fname, t, tm->id);
+#endif
     return tm->id;
 }
 
@@ -330,7 +332,6 @@ int zselect_timer_new_at(struct zselect *zsel, struct timeval *at, void (*func)(
 #else            
     tm = g_new(struct ztimer, 1);
 #endif        
-    if (!tm) return -1;
     
     struct timeval now;
     gettimeofday(&now, NULL);
@@ -363,12 +364,11 @@ int zselect_timer_new_at(struct zselect *zsel, struct timeval *at, void (*func)(
     return tm->id;
 }
 
-#ifdef Z_LEAK_DEBUG_LIST
-void debug_kill_timer(char *file, int line, int id)
-#else    
-void zselect_timer_kill(struct zselect *zsel, int id)
-#endif    
+void zselect_timer_kill_dbg(struct zselect *zsel, int id, const char *fname)
 {
+#if 1
+	if (strncmp(fname, "rain", 4) == 0) dbg("zselect_kill_timer(%d)\n", id);
+#endif
     struct ztimer *tm;
     int k = 0;
 	//dbg("__kill_timer(%d)\n", id);
@@ -377,11 +377,7 @@ void zselect_timer_kill(struct zselect *zsel, int id)
             struct ztimer *tt = tm;
             del_from_list(tm);
             tm = tm->prev;
-#ifdef Z_LEAK_DEBUG_LIST        
-            debug_g_free(file, line, tt);
-#else        
             g_free(tt);
-#endif        
             k++;
         }
     }
@@ -926,7 +922,7 @@ void zselect_hint(struct zselect *zsel, const char *fmt, ...){
 	va_end(ap);
 }
 
-void zselect_handle_profile(struct zselect *zsel, struct timeval *start, void *fce, char *fname){
+void zselect_handle_profile(struct zselect *zsel, struct timeval *start, void *fce, const char *fname){
 	struct timeval stop;
 	double d;
 
